%define majver %(echo %version | cut -d. -f1-2)
Name:          libgupnp
Version:       1.6.8
Release:       1mamba
Summary:       An object-oriented open source framework for creating UPnP devices and control points
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://wiki.gnome.org/Projects/GUPnP
Source:        https://download.gnome.org/sources/gupnp/%{majver}/gupnp-%{version}.tar.xz
License:       LGPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libgcc
BuildRequires: libglib-devel
BuildRequires: libgssdp-devel
BuildRequires: libsoup-devel
BuildRequires: libxml2-devel
## AUTOBUILDREQ-END

%description
GUPnP is an object-oriented open source framework for creating UPnP devices and control points, written in C using GObject and libsoup. The GUPnP API is intended to be easy to use, efficient and flexible. 
GUPnP implements the UPnP specification: resource announcement and discovery, description, control, event notification, and presentation (GUPnP includes basic web server functionality through libsoup). GUPnP does not include helpers for construction or control of specific standardized resources (e.g. MediaServer); this is left for higher level libraries utilizing the GUPnP framework.

%package devel
Summary:       Devel package for %{name}
Group:         Development/Libraries
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description devel
GUPnP is an object-oriented open source framework for creating UPnP devices and control points, written in C using GObject and libsoup. The GUPnP API is intended to be easy to use, efficient and flexible. 
GUPnP implements the UPnP specification: resource announcement and discovery, description, control, event notification, and presentation (GUPnP includes basic web server functionality through libsoup). GUPnP does not include helpers for construction or control of specific standardized resources (e.g. MediaServer); this is left for higher level libraries utilizing the GUPnP framework.
This package contains static libraries and header files needed for development.

%package tools
Summary:       Tools package for %{name}
Group:         System/Tools
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description tools
GUPnP is an object-oriented open source framework for creating UPnP devices and control points, written in C using GObject and libsoup. The GUPnP API is intended to be easy to use, efficient and flexible. 
GUPnP implements the UPnP specification: resource announcement and discovery, description, control, event notification, and presentation (GUPnP includes basic web server functionality through libsoup). GUPnP does not include helpers for construction or control of specific standardized resources (e.g. MediaServer); this is left for higher level libraries utilizing the GUPnP framework.
This package contains tools provided with %{name}.


%prep
%setup -q -n gupnp-%{version}

%build
%meson \
   -Dgtk_doc=true

%meson_build

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%meson_install

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"



%files
%defattr(-,root,root)
%{_libdir}/libgupnp-%{majver}.so.*
%{_libdir}/girepository-1.0/GUPnP-%{majver}.typelib
%doc AUTHORS COPYING

%files tools
%defattr(-,root,root)
%{_bindir}/gupnp-binding-tool-%{majver}
%{_mandir}/man1/gupnp-binding-tool-%{majver}.1*

%files devel
%defattr(-,root,root)
%dir %{_includedir}/gupnp-%{majver}
%dir %{_includedir}/gupnp-%{majver}/libgupnp
%{_includedir}/gupnp-%{majver}/libgupnp/*.h
%{_libdir}/libgupnp-%{majver}.so
%{_datadir}/gir-1.0/GUPnP-%{majver}.gir
%{_datadir}/vala/vapi/gupnp-%{majver}.deps
%{_datadir}/vala/vapi/gupnp-%{majver}.vapi
%{_libdir}/pkgconfig/*.pc
%dir %{_docdir}/gupnp-%{majver}
%{_docdir}/gupnp-%{majver}/*
%doc NEWS

%changelog
* Sat Jan 18 2025 Automatic Build System <autodist@openmamba.org> 1.6.8-1mamba
- automatic version update by autodist

* Tue Sep 24 2024 Automatic Build System <autodist@openmamba.org> 1.6.7-1mamba
- automatic version update by autodist

* Fri Nov 03 2023 Automatic Build System <autodist@mambasoft.it> 1.6.6-1mamba
- automatic version update by autodist

* Tue Aug 01 2023 Automatic Build System <autodist@mambasoft.it> 1.6.5-1mamba
- automatic version update by autodist

* Sun Jul 02 2023 Automatic Build System <autodist@mambasoft.it> 1.6.4-1mamba
- automatic version update by autodist

* Sat Dec 17 2022 Automatic Build System <autodist@mambasoft.it> 1.6.3-1mamba
- automatic version update by autodist

* Mon Nov 21 2022 Automatic Build System <autodist@mambasoft.it> 1.6.2-1mamba
- automatic version update by autodist

* Wed Nov 09 2022 Automatic Build System <autodist@mambasoft.it> 1.6.1-1mamba
- automatic version update by autodist

* Tue Sep 27 2022 Automatic Build System <autodist@mambasoft.it> 1.6.0-1mamba
- automatic version update by autodist

* Fri Jan 14 2022 Automatic Build System <autodist@mambasoft.it> 1.4.3-1mamba
- automatic version update by autodist

* Sun Jan 09 2022 Automatic Build System <autodist@mambasoft.it> 1.4.2-1mamba
- automatic version update by autodist

* Mon Jan 03 2022 Automatic Build System <autodist@mambasoft.it> 1.4.1-1mamba
- automatic version update by autodist

* Sun Jun 06 2021 Automatic Build System <autodist@mambasoft.it> 1.2.7-1mamba
- automatic version update by autodist

* Tue May 25 2021 Automatic Build System <autodist@mambasoft.it> 1.2.6-1mamba
- automatic version update by autodist

* Mon Aug 10 2020 Automatic Build System <autodist@mambasoft.it> 1.2.4-1mamba
- automatic version update by autodist

* Thu Jun 25 2020 Automatic Build System <autodist@mambasoft.it> 1.2.3-1mamba
- automatic version update by autodist

* Mon Apr 20 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.2-1mamba
- update to 1.2.2

* Tue Jul 31 2018 Automatic Build System <autodist@mambasoft.it> 1.0.3-1mamba
- automatic version update by autodist

* Mon Apr 24 2017 Automatic Build System <autodist@mambasoft.it> 1.0.2-1mamba
- automatic version update by autodist

* Sat Oct 15 2016 Automatic Build System <autodist@mambasoft.it> 1.0.1-1mamba
- automatic version update by autodist

* Thu Oct 13 2016 Automatic Build System <autodist@mambasoft.it> 1.0.0-1mamba
- automatic version update by autodist

* Tue Jun 21 2016 Automatic Build System <autodist@mambasoft.it> 0.20.18-1mamba
- automatic version update by autodist

* Sat May 07 2016 Automatic Build System <autodist@mambasoft.it> 0.20.17-1mamba
- automatic version update by autodist

* Sat Feb 13 2016 Automatic Build System <autodist@mambasoft.it> 0.20.16-1mamba
- automatic version update by autodist

* Fri Jan 01 2016 Automatic Build System <autodist@mambasoft.it> 0.20.15-1mamba
- automatic version update by autodist

* Mon May 11 2015 Automatic Build System <autodist@mambasoft.it> 0.20.14-1mamba
- automatic version update by autodist

* Wed Jan 28 2015 Automatic Build System <autodist@mambasoft.it> 0.20.13-1mamba
- automatic version update by autodist

* Wed Jun 04 2014 Automatic Build System <autodist@mambasoft.it> 0.20.12-1mamba
- automatic version update by autodist

* Sun May 04 2014 Automatic Build System <autodist@mambasoft.it> 0.20.11-1mamba
- automatic version update by autodist

* Tue Feb 04 2014 Automatic Build System <autodist@mambasoft.it> 0.20.10-1mamba
- automatic version update by autodist

* Sat Dec 14 2013 Automatic Build System <autodist@mambasoft.it> 0.20.9-1mamba
- automatic version update by autodist

* Thu Oct 31 2013 Automatic Build System <autodist@mambasoft.it> 0.20.8-1mamba
- automatic version update by autodist

* Wed Oct 16 2013 Automatic Build System <autodist@mambasoft.it> 0.20.7-1mamba
- automatic version update by autodist

* Sat Sep 07 2013 Automatic Build System <autodist@mambasoft.it> 0.20.6-1mamba
- automatic update by autodist

* Tue Aug 20 2013 Automatic Build System <autodist@mambasoft.it> 0.20.5-1mamba
- automatic version update by autodist

* Tue Jul 30 2013 Automatic Build System <autodist@mambasoft.it> 0.20.4-1mamba
- automatic version update by autodist

* Wed May 29 2013 Automatic Build System <autodist@mambasoft.it> 0.20.3-1mamba
- automatic version update by autodist

* Fri Apr 05 2013 Automatic Build System <autodist@mambasoft.it> 0.20.2-1mamba
- automatic version update by autodist

* Wed Mar 27 2013 Automatic Build System <autodist@mambasoft.it> 0.20.1-1mamba
- automatic version update by autodist

* Thu Jan 17 2013 Automatic Build System <autodist@mambasoft.it> 0.19.4-1mamba
- automatic version update by autodist

* Mon Jan 07 2013 Automatic Build System <autodist@mambasoft.it> 0.19.3-1mamba
- automatic version update by autodist

* Wed Oct 24 2012 Automatic Build System <autodist@mambasoft.it> 0.19.1-1mamba
- automatic version update by autodist

* Mon Oct 08 2012 Automatic Build System <autodist@mambasoft.it> 0.19.0-1mamba
- automatic version update by autodist

* Thu Sep 27 2012 Automatic Build System <autodist@mambasoft.it> 0.18.4-1mamba
- update to 0.18.4

* Mon Jun 28 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.13.2-2mamba
- rebuilt to add pkgconfig provides

* Tue Feb 16 2010 Automatic Build System <autodist@mambasoft.it> 0.13.2-1mamba
- automatic update by autodist

* Wed Nov 18 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 0.13.1-1mamba
- package created by autospec
